@@ -204,8 +204,9 @@ class MockCapture : public QObject
     public:
         MockCapture();
         Q_SCRIPTABLE Q_NOREPLY void clearAutoFocusHFR() {}
-        Q_SCRIPTABLE bool loadSequenceQueue(const QString &fileURL)
+        Q_SCRIPTABLE bool loadSequenceQueue(const QString &fileURL, bool ignoreTarget = false)
         {
+            Q_UNUSED(ignoreTarget)
             fprintf(stderr, "%d @@@MockCapture::loadSequenceQueue(%s)\n", __LINE__, fileURL.toLatin1().data());
             m_fileURL = fileURL;
             return true;
