@@ -88,7 +88,7 @@ protected:
     /**
      * @brief Register that a new image has been captured
      */
-    void captureComplete(const QString &filename, double exposureSeconds, const QString &filter, double hfr);
+    void captureComplete(const QVariantMap &metadata);
 
     // sequence of scheduler states that are expected
     QQueue<Ekos::SchedulerState> expectedSchedulerStates;
@@ -126,9 +126,10 @@ private:
     /**
      * @brief Fill the map of frames that have already been captured
      * @param expectedFrames comma separated list of <filter>:<count>
+     * @param imagepath base directory holding all images
      * @return true if everything was successful
      */
-    bool fillCapturedFramesMap(QString capturedFramesMap);
+    bool fillCapturedFramesMap(QString capturedFramesMap, QString imagepath);
 
     /**
      * @brief Determine the total count from a comma separated sequence of <filter>:<count>
