@@ -23,10 +23,11 @@
 #include <QJsonDocument>
 #include <QJsonArray>
 #include <QJsonObject>
-#include "polyfills/qstring_hash.h"
 #include <unordered_map>
+
 #include "config-kstars.h"
-#include "kstars_debug.h"
+// N.B. DO not remove, it is required for compilation.
+#include "polyfills/qstring_hash.h"
 
 #if __GNUC__ > 5
 #pragma GCC diagnostic push
@@ -355,4 +356,13 @@ bool RAWToJPEG(const QString &rawImage, const QString &output, QString &errorMes
  */
 double getAvailableRAM();
 
+void setGlobalSettings(const QVariantMap &settings);
+
+/**
+ * @brief sanitize Remove all illegal characters and spaces that can be problematic in file paths across all OSes.
+ * @param text String to sanitize
+ * @return Sanitized text
+ */
+QString sanitize(const QString &text);
+
 } // namespace KSUtils
