@@ -144,12 +144,29 @@ class Analyze : public QWidget, public Ui::Analyze
                 bool success;
                 double temperature;
                 QString filter;
+
+                // Standard focus parameters
                 QString points;
+                QString curve;
+                QString title;
                 QVector<double> positions; // Double to be more friendly to QCustomPlot addData.
                 QVector<double> hfrs;
+
+                // Adaptive focus parameters
+                int tempTicks;
+                double altitude;
+                int altTicks, totalTicks, adaptedPosition;
+
+                // false for adaptiveFocus.
+                bool standardSession = true;
+
                 FocusSession() : Session(0, 0, FOCUS_Y, nullptr) {}
                 FocusSession(double start_, double end_, QCPItemRect *rect, bool ok, double temperature_,
-                             const QString &filter_, const QString &points_);
+                             const QString &filter_, const QString &points_, const QString &curve_, const QString &title_);
+                FocusSession(double start_, double end_, QCPItemRect *rect,
+                             const QString &filter_, double temperature_, int tempTicks_, double altitude_,
+                             int altTicks_, int totalTicks_, int position_);
+                double focusPosition();
         };
 
     public slots:
@@ -168,7 +185,9 @@ class Analyze : public QWidget, public Ui::Analyze
 
         // From Focus
         void autofocusStarting(double temperature, const QString &filter);
-        void autofocusComplete(const QString &filter, const QString &points);
+        void autofocusComplete(const QString &filter, const QString &points, const QString &curve, const QString &title);
+        void adaptiveFocusComplete(const QString &filter, double temperature, int tempTicks,
+                                   double altitude, int altTicks, int totalTicks, int position);
         void autofocusAborted(const QString &filter, const QString &points);
         void newTemperature(double temperatureDelta, double temperature);
 
@@ -206,7 +225,10 @@ class Analyze : public QWidget, public Ui::Analyze
                                     double hfr, int numStars, int median, double eccentricity, bool batchMode = false);
         void processCaptureAborted(double time, double exposureSeconds, bool batchMode = false);
         void processAutofocusStarting(double time, double temperature, const QString &filter, bool batchMode = false);
-        void processAutofocusComplete(double time, const QString &filter, const QString &points, bool batchMode = false);
+        void processAutofocusComplete(double time, const QString &filter, const QString &points, const QString &curve,
+                                      const QString &title, bool batchMode = false);
+        void processAdaptiveFocusComplete(double time, const QString &filter, double temperature, int tempTicks,
+                                          double altitude, int altTicks, int totalTicks, int position, bool batchMode = false);
         void processAutofocusAborted(double time, const QString &filter, const QString &points, bool batchMode = false);
         void processTemperature(double time, double temperature, bool batchMode = false);
         void processGuideState(double time, const QString &state, bool batchMode = false);
@@ -314,6 +336,7 @@ class Analyze : public QWidget, public Ui::Analyze
         void addHFR(double hfr, int numCaptureStars, int median, double eccentricity,
                     const double time, double startTime);
         void addTemperature(double temperature, const double time);
+        void addFocusPosition(double focusPosition, double time);
         void addTargetDistance(double targetDistance, const double time);
 
         // Initialize the graphs (axes, linestyle, pen, name, checkbox callbacks).
@@ -335,7 +358,7 @@ class Analyze : public QWidget, public Ui::Analyze
         void initInputSelection();
 
         // Displays the focus positions and HFRs on the graphics plot.
-        void displayFocusGraphics(const QVector<double> &positions, const QVector<double> &hfrs, bool success);
+        void displayFocusGraphics(const QVector<double> &positions, const QVector<double> &hfrs, const QString &curve, const QString &title, bool success);
         // Displays the guider ra and dec drift plot, and computes RMS errors.
         void displayGuideGraphics(double start, double end, double *raRMS,
                                   double *decRMS, double *totalRMS, int *numSamples);
