@@ -136,7 +136,7 @@ OpticalTrainManager::OpticalTrainManager() : QDialog(KStars::Instance())
 
     connect(addB, &QPushButton::clicked, this, [this]()
     {
-        addOpticalTrain(false, i18n("New Train"));
+        addOpticalTrain(m_TrainNames.count(), i18n("New Train"));
         m_OpticalTrainsModel->select();
         refreshModel();
         trainNamesList->setCurrentRow(trainNamesList->count() - 1);
@@ -177,6 +177,15 @@ OpticalTrainManager::OpticalTrainManager() : QDialog(KStars::Instance())
     m_CheckMissingDevicesTimer.setInterval(5000);
     m_CheckMissingDevicesTimer.setSingleShot(true);
     connect(&m_CheckMissingDevicesTimer, &QTimer::timeout, this, &OpticalTrainManager::checkMissingDevices);
+
+    m_DelegateTimer.setInterval(1000);
+    m_DelegateTimer.setSingleShot(true);
+    connect(&m_DelegateTimer, &QTimer::timeout, this, [this]()
+    {
+        if (m_Profile)
+            setProfile(m_Profile);
+    });
+
     initModel();
 }
 
@@ -185,8 +194,7 @@ OpticalTrainManager::OpticalTrainManager() : QDialog(KStars::Instance())
 ////////////////////////////////////////////////////////////////////////////
 void OpticalTrainManager::initModel()
 {
-    QSqlDatabase userdb = QSqlDatabase::cloneDatabase(KStarsData::Instance()->userdb()->GetDatabase(), "opticaltrains_db");
-    userdb.open();
+    auto userdb = QSqlDatabase::database(KStarsData::Instance()->userdb()->connectionName());
     m_OpticalTrainsModel = new QSqlTableModel(this, userdb);
     connect(m_OpticalTrainsModel, &QSqlTableModel::dataChanged, this, [this]()
     {
@@ -241,20 +249,32 @@ void OpticalTrainManager::refreshModel()
 ////////////////////////////////////////////////////////////////////////////
 void OpticalTrainManager::setProfile(const QSharedPointer<ProfileInfo> &profile)
 {
-    // Are we still updating delegates? If yes, return.
-    if (syncDelegatesToDevices())
-    {
-        m_CheckMissingDevicesTimer.start();
-        return;
-    }
+    m_DelegateTimer.stop();
 
-    // Once we're done, let's continue with train generation.
+    // Load optical train model
     if (m_Profile != profile)
     {
         m_Profile = profile;
         refreshModel();
     }
 
+    // Are we still updating delegates? If yes, return.
+    if (syncDelegatesToDevices())
+    {
+        m_CheckMissingDevicesTimer.start();
+
+        // Start delegate timer to ensure no more changes are pending.
+        m_DelegateTimer.start();
+    }
+    else
+        checkOpticalTrains();
+}
+
+////////////////////////////////////////////////////////////////////////////
+///
+////////////////////////////////////////////////////////////////////////////
+void OpticalTrainManager::checkOpticalTrains()
+{
     if (m_OpticalTrains.empty())
     {
         generateOpticalTrains();
@@ -291,16 +311,19 @@ void OpticalTrainManager::setProfile(const QSharedPointer<ProfileInfo> &profile)
 void OpticalTrainManager::generateOpticalTrains()
 {
     // We should have primary train
-    addOpticalTrain(true, i18n("Primary"));
+    addOpticalTrain(0, i18n("Primary"));
     // Check if need secondary train
-    if (m_CameraNames.count() > 2)
-        addOpticalTrain(false, i18n("Secondary"));
+    if (cameraComboBox->count() > 2)
+        addOpticalTrain(1, i18n("Secondary"));
+    // Check if need teritary train
+    if (cameraComboBox->count() > 3)
+        addOpticalTrain(2, i18n("Teritary"));
 }
 
 ////////////////////////////////////////////////////////////////////////////
 ///
 ////////////////////////////////////////////////////////////////////////////
-QString OpticalTrainManager::addOpticalTrain(bool main, const QString &name)
+QString OpticalTrainManager::addOpticalTrain(uint8_t index, const QString &name)
 {
     QVariantMap train;
     train["profile"] = m_Profile->id;
@@ -319,10 +342,19 @@ QString OpticalTrainManager::addOpticalTrain(bool main, const QString &name)
     if (KStars::Instance()->data()->userdb()->getLastOpticalElement(opticalElement))
         train["scope"] = opticalElement["name"].toString();
 
-    if (main)
-        train["camera"] = cameraComboBox->itemText(cameraComboBox->count() > 1 ? 1 : 0);
-    else
-        train["camera"] = cameraComboBox->itemText(cameraComboBox->count() > 2 ? 2 : 0);
+    train["camera"] = "--";
+    // Primary train
+    if (index == 0 && cameraComboBox->count() > 1)
+        train["camera"] = cameraComboBox->itemText(1);
+    // Any other trains
+    else if (index > 0)
+    {
+        // For 2nd train and beyond, we get the N camera appropiate for this train if one exist.
+        // We add + 1 because first element in combobox is "--"
+        auto cameraIndex = index + 1;
+        if (cameraComboBox->count() >= cameraIndex)
+            train["camera"] = cameraComboBox->itemText(cameraIndex);
+    }
 
     KStarsData::Instance()->userdb()->AddOpticalTrain(train);
     return train["name"].toString();
