@@ -425,6 +425,22 @@ void CaptureModuleState::processGuidingFailed()
     }
 }
 
+void CaptureModuleState::updateAdaptiveFocusState(bool success)
+{
+    // Always process the adaptive focus state change, incl if a MF has also just started
+    if (success)
+        qCDebug(KSTARS_EKOS_CAPTURE) << "Adaptive focus completed successfully";
+    else
+        qCDebug(KSTARS_EKOS_CAPTURE) << "Adaptive focus failed";
+
+    m_refocusState->setAutoFocusReady(true);
+    // forward to the active job
+    if (m_activeJob != nullptr)
+        m_activeJob->setAutoFocusReady(true);
+
+    setFocusState(FOCUS_COMPLETE);
+}
+
 void CaptureModuleState::updateFocusState(FocusState state)
 {
     if (state != m_FocusState)
@@ -476,7 +492,7 @@ void CaptureModuleState::updateFocusState(FocusState state)
 
 bool CaptureModuleState::startFocusIfRequired()
 {
-    // Do not start focus if:
+    // Do not start focus or adaptive focus if:
     // 1. There is no active job, or
     // 2. Target frame is not LIGHT
     // 3. Capture is preview only
@@ -514,6 +530,11 @@ bool CaptureModuleState::startFocusIfRequired()
             emit checkFocus(Options::hFRDeviation() == 0.0 ? 0.1 : Options::hFRDeviation());
             qCDebug(KSTARS_EKOS_CAPTURE) << "In-sequence focusing started...";
             break;
+        case RefocusState::REFOCUS_ADAPTIVE:
+            m_refocusState->setAdaptiveFocusDone(true);
+            emit adaptiveFocus();
+            qCDebug(KSTARS_EKOS_CAPTURE) << "Adaptive focus started...";
+            break;
         case RefocusState::REFOCUS_TEMPERATURE:
         case RefocusState::REFOCUS_TIME_ELAPSED:
         case RefocusState::REFOCUS_POST_MF:
@@ -778,6 +799,83 @@ void CaptureModuleState::setGuideDeviation(double deviation_rms)
     }
 }
 
+void CaptureModuleState::addDownloadTime(double time)
+{
+    totalDownloadTime += time;
+    downloadsCounter++;
+}
+
+bool CaptureModuleState::setDarkFlatExposure(SequenceJob *job)
+{
+    const auto darkFlatFilter = job->getCoreProperty(SequenceJob::SJ_Filter).toString();
+    const auto darkFlatBinning = job->getCoreProperty(SequenceJob::SJ_Binning).toPoint();
+    const auto darkFlatADU = job->getCoreProperty(SequenceJob::SJ_TargetADU).toInt();
+
+    for (auto &oneJob : allJobs())
+    {
+        if (oneJob->getFrameType() != FRAME_FLAT)
+            continue;
+
+        const auto filter = oneJob->getCoreProperty(SequenceJob::SJ_Filter).toString();
+
+        // Match filter, if one exists.
+        if (!darkFlatFilter.isEmpty() && darkFlatFilter != filter)
+            continue;
+
+        // Match binning
+        const auto binning = oneJob->getCoreProperty(SequenceJob::SJ_Binning).toPoint();
+        if (darkFlatBinning != binning)
+            continue;
+
+        // Match ADU, if used.
+        const auto adu = oneJob->getCoreProperty(SequenceJob::SJ_TargetADU).toInt();
+        if (job->getFlatFieldDuration() == DURATION_ADU)
+        {
+            if (darkFlatADU != adu)
+                continue;
+        }
+
+        // Now get the exposure
+        job->setCoreProperty(SequenceJob::SJ_Exposure, oneJob->getCoreProperty(SequenceJob::SJ_Exposure).toDouble());
+
+        return true;
+    }
+    return false;
+}
+
+void CaptureModuleState::checkSeqBoundary(QUrl sequenceURL)
+{
+    // No updates during meridian flip
+    if (getMeridianFlipState()->getMeridianFlipStage() >= MeridianFlipState::MF_ALIGNING)
+        return;
+
+    auto placeholderPath = PlaceholderPath(sequenceURL.toLocalFile());
+    setNextSequenceID(placeholderPath.checkSeqBoundary(*getActiveJob(), targetName()));
+}
+
+void CaptureModuleState::addCapturedFrame(const QString &signature)
+{
+    SchedulerJob::CapturedFramesMap::iterator frame_item = m_capturedFramesMap.find(signature);
+    if (m_capturedFramesMap.end() != frame_item)
+        frame_item.value()++;
+    else m_capturedFramesMap[signature] = 1;
+
+}
+
+void CaptureModuleState::removeCapturedFrameCount(const QString &signature, uint16_t count)
+{
+    SchedulerJob::CapturedFramesMap::iterator frame_item = m_capturedFramesMap.find(signature);
+    if (m_capturedFramesMap.end() != frame_item)
+    {
+        // remove the frame count
+        frame_item.value() = frame_item.value() - count;
+        // clear signature entry if none left
+        if (frame_item.value() <= 0)
+            m_capturedFramesMap.remove(signature);
+    }
+}
+
+
 
 
 
