@@ -49,9 +49,9 @@ void CapturePreviewWidget::shareSchedulerProcess(Ekos::Scheduler *process)
 void CapturePreviewWidget::shareMountProcess(Ekos::Mount *process)
 {
     mountProcess = process;
-    connect(mountProcess, &Ekos::Mount::newTarget, [&](SkyObject currentObject)
+    connect(mountProcess, &Ekos::Mount::newTargetName, this, [this](const QString & name)
     {
-        m_mountTarget = currentObject.name();
+        m_mountTarget = name;
     });
 }
 
@@ -76,14 +76,15 @@ void CapturePreviewWidget::updateJobProgress(Ekos::SequenceJob *job, const QShar
     else
         m_currentFrame.target = "";
 
-    m_currentFrame.filterName = job->getCoreProperty(SequenceJob::SJ_Filter).toString();
-    m_currentFrame.exptime    = job->getCoreProperty(SequenceJob::SJ_Exposure).toDouble();
-    m_currentFrame.binning    = job->getCoreProperty(SequenceJob::SJ_Binning).toPoint();
-    m_currentFrame.gain       = job->getCoreProperty(SequenceJob::SJ_Gain).toDouble();
-    m_currentFrame.offset     = job->getCoreProperty(SequenceJob::SJ_Offset).toDouble();
-    m_currentFrame.filename   = data->filename();
-    m_currentFrame.width      = data->width();
-    m_currentFrame.height     = data->height();
+    m_currentFrame.filterName  = job->getCoreProperty(SequenceJob::SJ_Filter).toString();
+    m_currentFrame.exptime     = job->getCoreProperty(SequenceJob::SJ_Exposure).toDouble();
+    m_currentFrame.targetdrift = -1.0; // will be updated later
+    m_currentFrame.binning     = job->getCoreProperty(SequenceJob::SJ_Binning).toPoint();
+    m_currentFrame.gain        = job->getCoreProperty(SequenceJob::SJ_Gain).toDouble();
+    m_currentFrame.offset      = job->getCoreProperty(SequenceJob::SJ_Offset).toDouble();
+    m_currentFrame.filename    = data->filename();
+    m_currentFrame.width       = data->width();
+    m_currentFrame.height      = data->height();
 
     const auto ISOIndex = job->getCoreProperty(SequenceJob::SJ_Offset).toInt();
     if (ISOIndex >= 0 && ISOIndex <= captureProcess->captureISOS->count())
@@ -129,40 +130,58 @@ void CapturePreviewWidget::deleteCurrentFrame()
     QFile *file = new QFile(current.filename);
 
     // prepare a warning dialog
+    // move to trash or delete permanently
+    QCheckBox *permanentlyDeleteCB = new QCheckBox(i18n("Delete directly, do not move to trash."));
+    permanentlyDeleteCB->setChecked(m_permanentlyDelete);
+    KSMessageBox::Instance()->setCheckBox(permanentlyDeleteCB);
+    connect(permanentlyDeleteCB, &QCheckBox::toggled, this, [this](bool checked)
+    {
+        this->m_permanentlyDelete = checked;
+    });
     // Delete
     connect(KSMessageBox::Instance(), &KSMessageBox::accepted, this, [this, pos, file]()
     {
         KSMessageBox::Instance()->disconnect(this);
-
-        if (file->remove() == true)
+        bool success = false;
+        if (this->m_permanentlyDelete == false && (success = file->moveToTrash()))
+        {
+            qCInfo(KSTARS_EKOS_CAPTURE) << overlay->currentFrame().filename << "moved to Trash.";
+        }
+        else if (this->m_permanentlyDelete && (success = file->remove()))
         {
             qCInfo(KSTARS_EKOS_CAPTURE) << overlay->currentFrame().filename << "deleted.";
         }
+
+        if (success)
+        {
+            // delete it from the history and update the FITS view
+            if (overlay->deleteFrame(pos) && overlay->hasFrames())
+            {
+                m_fitsPreview->loadFile(overlay->currentFrame().filename);
+                // Hint: since the FITSView loads in the background, we have to wait for FITSView::load() to enable the layer
+            }
+            else
+            {
+                m_fitsPreview->clearData();
+                overlay->setEnabled(true);
+            }
+        }
         else
         {
             qCWarning(KSTARS_EKOS_CAPTURE) << "Deleting" << overlay->currentFrame().filename << "failed!";
             // give up
             overlay->setEnabled(true);
-            return;
-        }
-
-        // delete it from the history and update the FITS view
-        if (overlay->deleteFrame(pos) && overlay->hasFrames())
-        {
-            m_fitsPreview->loadFile(overlay->currentFrame().filename);
-            // Hint: since the FITSView loads in the background, we have to wait for FITSView::load() to enable the layer
-        }
-        else
-        {
-            m_fitsPreview->clearData();
-            overlay->setEnabled(true);
         }
+        // clear the check box
+        KSMessageBox::Instance()->setCheckBox(nullptr);
     });
 
     // Cancel
     connect(KSMessageBox::Instance(), &KSMessageBox::rejected, this, [this]()
     {
         KSMessageBox::Instance()->disconnect(this);
+        // clear the check box
+        KSMessageBox::Instance()->setCheckBox(nullptr);
         //do nothing
         overlay->setEnabled(true);
     });
@@ -171,7 +190,7 @@ void CapturePreviewWidget::deleteCurrentFrame()
     QFileInfo fileinfo(current.filename);
     KSMessageBox::Instance()->warningContinueCancel(i18n("Do you really want to delete %1 from the file system?",
             fileinfo.fileName()),
-            i18n("Delete %1", fileinfo.fileName()), 15, false, i18n("Delete"));
+            i18n("Delete %1", fileinfo.fileName()), 0, false, i18n("Delete"));
 
 }
 
@@ -217,7 +236,7 @@ void CapturePreviewWidget::reset()
 
 void CapturePreviewWidget::updateCaptureStatus(Ekos::CaptureState status)
 {
-    captureStatus->setText(Ekos::getCaptureStatusString(status));
+    captureStatusWidget->setCaptureState(status);
 
     // update the data of the overlay
     if (status == Ekos::CAPTURE_IMAGE_RECEIVED)
@@ -230,6 +249,12 @@ void CapturePreviewWidget::updateCaptureStatus(Ekos::CaptureState status)
     captureCountsWidget->updateCaptureStatus(status);
 }
 
+void CapturePreviewWidget::updateTargetDistance(double targetDiff)
+{
+    // forward it to the overlay
+    overlay->updateTargetDistance(targetDiff);
+}
+
 void CapturePreviewWidget::updateCaptureCountDown(int delta)
 {
     // forward to sub widget
