@@ -70,12 +70,7 @@ void PlaceholderPath::processJobInfo(SequenceJob *job, const QString &targetName
         frameType = "DarkFlat";
 
     // Sanitize name
-    QString tempTargetName = targetName;
-    tempTargetName.replace( QRegularExpression("\\s|/|\\(|\\)|:|\\*|~|\"" ), "_" )
-    // Remove any two or more __
-    .replace( QRegularExpression("_{2,}"), "_")
-    // Remove any _ at the end
-    .replace( QRegularExpression("_$"), "");
+    QString tempTargetName = KSUtils::sanitize(targetName);
 
     // Because scheduler sets the target name in capture module
     // it would be the same as the raw prefix
@@ -160,20 +155,12 @@ void PlaceholderPath::addJob(SequenceJob *job, const QString &targetName)
 {
     auto frameType = job->getFrameType();
     auto frameTypeString = getFrameType(job->getFrameType());
-    QString imagePrefix = targetName;
+    QString imagePrefix = KSUtils::sanitize(targetName);
 
     const auto isDarkFlat = job->getCoreProperty(SequenceJob::SJ_DarkFlat).toBool();
     if (isDarkFlat)
         frameTypeString = "DarkFlat";
 
-    // JM 2019-11-26: In case there is no job target name set
-    // BUT target name is set, we update the prefix to include
-    // the target name, which is usually set by the scheduler.
-    if (imagePrefix.isEmpty() && !targetName.isEmpty())
-    {
-        imagePrefix = targetName;
-    }
-
     QString tempPrefix = constructPrefix(job, imagePrefix);
 
     job->setCoreProperty(SequenceJob::SJ_FullPrefix, tempPrefix);
@@ -186,7 +173,7 @@ void PlaceholderPath::addJob(SequenceJob *job, const QString &targetName)
     if (targetName.isEmpty())
         directoryPostfix = QDir::separator() + frameTypeString;
     else
-        directoryPostfix = QDir::separator() + targetName + QDir::separator() + frameTypeString;
+        directoryPostfix = QDir::separator() + imagePrefix + QDir::separator() + frameTypeString;
 
 
     if ((frameType == FRAME_LIGHT || frameType == FRAME_FLAT || frameType == FRAME_NONE || isDarkFlat)
@@ -199,10 +186,11 @@ void PlaceholderPath::addJob(SequenceJob *job, const QString &targetName)
 QString PlaceholderPath::constructPrefix(const SequenceJob *job, const QString &imagePrefix)
 {
     CCDFrameType frameType = job->getFrameType();
+    auto placeholderFormat = job->getCoreProperty(SequenceJob::SJ_PlaceholderFormat).toString();
     auto filter = job->getCoreProperty(SequenceJob::SJ_Filter).toString();
-    auto filterEnabled = job->getCoreProperty(SequenceJob::SJ_FilterPrefixEnabled).toBool();
-    auto expEnabled = job->getCoreProperty(SequenceJob::SJ_ExpPrefixEnabled).toBool();
-    auto tsEnabled = job->getCoreProperty(SequenceJob::SJ_TimeStampPrefixEnabled).toBool();
+    auto filterEnabled = job->getCoreProperty(SequenceJob::SJ_FilterPrefixEnabled).toBool() || placeholderFormat.contains("%F");
+    auto expEnabled = job->getCoreProperty(SequenceJob::SJ_ExpPrefixEnabled).toBool() || placeholderFormat.contains("%e");
+    auto tsEnabled = job->getCoreProperty(SequenceJob::SJ_TimeStampPrefixEnabled).toBool() || placeholderFormat.contains("%D");
 
     double exposure = job->getCoreProperty(SequenceJob::SJ_Exposure).toDouble();
 
@@ -298,12 +286,7 @@ QString PlaceholderPath::generateFilename(const QString &directory,
         const bool glob,
         const bool gettingSignature) const
 {
-    QString targetNameSanitized = targetName;
-    targetNameSanitized.replace( QRegularExpression("\\s|/|\\(|\\)|:|\\*|\\+|~|\"" ), "_" )
-    // Remove any two or more __
-    .replace( QRegularExpression("_{2,}"), "_")
-    // Remove any _ at the end
-    .replace( QRegularExpression("_$"), "");
+    QString targetNameSanitized = KSUtils::sanitize(targetName);
     int i = 0;
 
     QString tempFilename = filename;
@@ -313,6 +296,10 @@ QString PlaceholderPath::generateFilename(const QString &directory,
     else
         currentDir = QDir::toNativeSeparators(KSPaths::writableLocation(QStandardPaths::TempLocation) + "/kstars/");
 
+    if(!currentDir.isEmpty() && !currentDir.endsWith(QDir::separator())
+            && !format.isEmpty() && !format.startsWith(QDir::separator()))
+        currentDir.append(QDir::separator());
+
     QString tempFormat = currentDir + format + "_%s" + QString::number(formatSuffix);
 
     QRegularExpressionMatch match;
@@ -368,16 +355,7 @@ QString PlaceholderPath::generateFilename(const QString &directory,
         }
         else if ((match.captured("name") == "target") || (match.captured("name") == "t"))
         {
-            if (tempFormat.indexOf(QDir::separator(), match.capturedStart()) != -1)
-            {
-                // in the directory part of the path
-                replacement = targetNameSanitized;
-            }
-            else
-            {
-                // in the basename part of the path
-                replacement = targetNameSanitized;
-            }
+            replacement = targetNameSanitized;
         }
         // Disable for now %d & %p tags to simplfy
         //        else if ((match.captured("name") == "directory") || (match.captured("name") == "d") ||
