@@ -281,6 +281,11 @@ void SequenceJobState::prepareTargetFilter(CCDFrameType frameType, bool isPrevie
         if (isInitialized(CaptureModuleState::ACTION_FILTER) == false)
         {
             prepareActions[CaptureModuleState::ACTION_FILTER] = false;
+
+            // Don't perform autofocus on preview or calibration frames or if Autofocus is not ready yet.
+            if (isPreview || frameType != FRAME_LIGHT || autoFocusReady == false)
+                m_filterPolicy = static_cast<FilterManager::FilterPolicy>(m_filterPolicy & ~FilterManager::AUTOFOCUS_POLICY);
+
             emit readFilterPosition();
         }
         else if (targetFilterID != m_CaptureModuleState->currentFilterID)
@@ -332,8 +337,7 @@ void SequenceJobState::prepareRotatorCheck()
         if (isInitialized(CaptureModuleState::ACTION_ROTATOR))
         {
             prepareActions[CaptureModuleState::ACTION_ROTATOR] = false;
-            // RawAngle = PA + Offset / Multiplier -> see Capture::Capture()
-            double rawAngle = (targetPositionAngle + Options::pAOffset()) / Options::pAMultiplier();
+            double rawAngle = RotatorUtils::Instance()->calcRotatorAngle(targetPositionAngle);
             emit prepareState(CAPTURE_SETTING_ROTATOR);
             emit setRotatorAngle(&rawAngle);
         }
@@ -582,8 +586,7 @@ IPState SequenceJobState::checkFlatSyncFocus()
         return IPS_BUSY;
     }
 
-    if (m_frameType == FRAME_FLAT && autoFocusReady && Options::flatSyncFocus() &&
-            flatSyncStatus != FS_COMPLETED)
+    if (m_frameType == FRAME_FLAT && Options::flatSyncFocus() && flatSyncStatus != FS_COMPLETED)
     {
         flatSyncStatus = FS_BUSY;
         emit flatSyncFocus(targetFilterID);
@@ -729,15 +732,12 @@ void SequenceJobState::setCurrentCCDTemperature(double currentTemperature)
 
 void SequenceJobState::setCurrentRotatorPositionAngle(double rotatorAngle, IPState state)
 {
-    // PA = RawAngle * Multiplier - Offset -> see Capture::Capture()
-    double currentPositionAngle = range360(rotatorAngle * Options::pAMultiplier() - Options::pAOffset());
-    if (currentPositionAngle > 180)
-        currentPositionAngle -= 360.0;
+    double currentPositionAngle = RotatorUtils::Instance()->calcCameraAngle(rotatorAngle, false);
 
     if (isInitialized(CaptureModuleState::ACTION_ROTATOR))
     {
         // TODO introduce settle time
-        // TODO make sure rotator has fully stopped
+        // TODO make sure rotator has fully stopped -> see 'align.cpp' captureAndSolve()
         if (fabs(currentPositionAngle - targetPositionAngle) * 60 <= Options::astrometryRotatorThreshold()
                 && state != IPS_BUSY)
             prepareActions[CaptureModuleState::ACTION_ROTATOR] = true;
