@@ -21,58 +21,42 @@
 namespace EkosLive
 {
 
-Cloud::Cloud(Ekos::Manager * manager): m_Manager(manager)
+Cloud::Cloud(Ekos::Manager * manager, QVector<QSharedPointer<NodeManager>> &nodeManagers):
+    m_Manager(manager), m_NodeManagers(nodeManagers)
 {
-    connect(&m_WebSocket, &QWebSocket::connected, this, &Cloud::onConnected);
-    connect(&m_WebSocket, &QWebSocket::disconnected, this, &Cloud::onDisconnected);
-    connect(&m_WebSocket, static_cast<void(QWebSocket::*)(QAbstractSocket::SocketError)>(&QWebSocket::error), this,
-            &Cloud::onError);
+    for (auto &nodeManager : m_NodeManagers)
+    {
+        if (nodeManager->cloud() == nullptr)
+            continue;
+
+        connect(nodeManager->cloud(), &Node::connected, this, &Cloud::onConnected);
+        connect(nodeManager->cloud(), &Node::disconnected, this, &Cloud::onDisconnected);
+        connect(nodeManager->cloud(), &Node::onTextReceived, this, &Cloud::onTextReceived);
+    }
 
     connect(&watcher, &QFutureWatcher<bool>::finished, this, &Cloud::sendImage, Qt::UniqueConnection);
-
     connect(this, &Cloud::newImage, this, &Cloud::uploadImage);
-
     connect(Options::self(), &Options::EkosLiveCloudChanged, this, &Cloud::updateOptions);
 }
 
-void Cloud::connectServer()
+///////////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////////
+bool Cloud::isConnected() const
 {
-    QUrl requestURL(m_URL);
-
-    QUrlQuery query;
-    query.addQueryItem("username", m_AuthResponse["username"].toString());
-    query.addQueryItem("token", m_AuthResponse["token"].toString());
-    if (m_AuthResponse.contains("remoteToken"))
-        query.addQueryItem("remoteToken", m_AuthResponse["remoteToken"].toString());
-    query.addQueryItem("cloudEnabled", Options::ekosLiveCloud() ? "true" : "false");
-    query.addQueryItem("email", m_AuthResponse["email"].toString());
-    query.addQueryItem("from_date", m_AuthResponse["from_date"].toString());
-    query.addQueryItem("to_date", m_AuthResponse["to_date"].toString());
-    query.addQueryItem("plan_id", m_AuthResponse["plan_id"].toString());
-    query.addQueryItem("type", m_AuthResponse["type"].toString());
-    query.addQueryItem("version", KSTARS_VERSION);
-
-    requestURL.setPath("/cloud/ekos");
-    requestURL.setQuery(query);
-
-    m_WebSocket.open(requestURL);
-
-    qCInfo(KSTARS_EKOS) << "Connecting to cloud websocket server at" << requestURL.toDisplayString();
-}
-
-void Cloud::disconnectServer()
-{
-    m_WebSocket.close();
+    return std::any_of(m_NodeManagers.begin(), m_NodeManagers.end(), [](auto & nodeManager)
+    {
+        return nodeManager->cloud() && nodeManager->cloud()->isConnected();
+    });
 }
 
 void Cloud::onConnected()
 {
-    qCInfo(KSTARS_EKOS) << "Connected to Cloud Websocket server at" << m_URL.toDisplayString();
+    auto node = qobject_cast<Node*>(sender());
+    if (!node)
+        return;
 
-    connect(&m_WebSocket, &QWebSocket::textMessageReceived,  this, &Cloud::onTextReceived);
-
-    m_isConnected = true;
-    m_ReconnectTries = 0;
+    qCInfo(KSTARS_EKOS) << "Connected to Cloud Websocket server at" << node->url().toDisplayString();
 
     emit connected();
 }
@@ -80,30 +64,15 @@ void Cloud::onConnected()
 void Cloud::onDisconnected()
 {
     qCInfo(KSTARS_EKOS) << "Disconnected from Cloud Websocket server.";
-    m_isConnected = false;
-
-    disconnect(&m_WebSocket, &QWebSocket::textMessageReceived,  this, &Cloud::onTextReceived);
-
     m_sendBlobs = true;
 
-    for (const QString &oneFile : temporaryFiles)
+    for (auto &oneFile : temporaryFiles)
         QFile::remove(oneFile);
     temporaryFiles.clear();
 
     emit disconnected();
 }
 
-void Cloud::onError(QAbstractSocket::SocketError error)
-{
-    qCritical(KSTARS_EKOS) << "Cloud Websocket connection error" << m_WebSocket.errorString();
-    if (error == QAbstractSocket::RemoteHostClosedError ||
-            error == QAbstractSocket::ConnectionRefusedError)
-    {
-        if (m_ReconnectTries++ < RECONNECT_MAX_TRIES)
-            QTimer::singleShot(RECONNECT_INTERVAL, this, SLOT(connectServer()));
-    }
-}
-
 void Cloud::onTextReceived(const QString &message)
 {
     qCInfo(KSTARS_EKOS) << "Cloud Text Websocket Message" << message;
@@ -117,19 +86,23 @@ void Cloud::onTextReceived(const QString &message)
 
     const QJsonObject msgObj = serverMessage.object();
     const QString command = msgObj["type"].toString();
-    //    const QJsonObject payload = msgObj["payload"].toObject();
-
-    //    if (command == commands[ALIGN_SET_FILE_EXTENSION])
-    //        extension = payload["ext"].toString();
     if (command == commands[SET_BLOBS])
         m_sendBlobs = msgObj["payload"].toBool();
     else if (command == commands[LOGOUT])
-        disconnectServer();
+    {
+        for (auto &nodeManager : m_NodeManagers)
+        {
+            if (nodeManager->cloud() == nullptr)
+                continue;
+
+            nodeManager->cloud()->disconnectServer();
+        }
+    }
 }
 
 void Cloud::upload(const QSharedPointer<FITSData> &data, const QString &uuid)
 {
-    if (m_isConnected == false || Options::ekosLiveCloud() == false  || m_sendBlobs == false)
+    if (Options::ekosLiveCloud() == false  || m_sendBlobs == false)
         return;
 
     m_UUID = uuid;
@@ -139,7 +112,7 @@ void Cloud::upload(const QSharedPointer<FITSData> &data, const QString &uuid)
 
 void Cloud::upload(const QString &filename, const QString &uuid)
 {
-    if (m_isConnected == false || Options::ekosLiveCloud() == false  || m_sendBlobs == false)
+    if (Options::ekosLiveCloud() == false  || m_sendBlobs == false)
         return;
 
     watcher.waitForFinished();
@@ -203,23 +176,32 @@ void Cloud::asyncUpload()
 
 void Cloud::uploadImage(const QByteArray &image)
 {
-    m_WebSocket.sendBinaryMessage(image);
+    for (auto &nodeManager : m_NodeManagers)
+    {
+        if (nodeManager->cloud() == nullptr)
+            continue;
+
+        nodeManager->cloud()->sendBinaryMessage(image);
+    }
 }
 
 void Cloud::updateOptions()
 {
     // In case cloud storage is toggled, inform cloud
     // websocket channel of this change.
-    if (m_isConnected)
+    QJsonObject payload = {{"name", "ekosLiveCloud"}, {"value", Options::ekosLiveCloud()}};
+    QJsonObject message =
     {
-        QJsonObject payload = {{"name", "ekosLiveCloud"}, {"value", Options::ekosLiveCloud()}};
-        QJsonObject message =
-        {
-            {"type",  commands[OPTION_SET]},
-            {"payload", payload}
-        };
+        {"type",  commands[OPTION_SET]},
+        {"payload", payload}
+    };
 
-        m_WebSocket.sendTextMessage(QJsonDocument(message).toJson(QJsonDocument::Compact));
+    for (auto &nodeManager : m_NodeManagers)
+    {
+        if (nodeManager->cloud() == nullptr)
+            continue;
+
+        nodeManager->cloud()->sendTextMessage(QJsonDocument(message).toJson(QJsonDocument::Compact));
     }
 }
 
