@@ -34,87 +34,68 @@
 
 namespace EkosLive
 {
-Message::Message(Ekos::Manager *manager): m_Manager(manager), m_DSOManager(CatalogsDB::dso_db_path())
+Message::Message(Ekos::Manager *manager, QVector<QSharedPointer<NodeManager>> &nodeManagers):
+    m_Manager(manager), m_NodeManagers(nodeManagers), m_DSOManager(CatalogsDB::dso_db_path())
 {
-    connect(&m_WebSocket, &QWebSocket::connected, this, &Message::onConnected);
-    connect(&m_WebSocket, &QWebSocket::disconnected, this, &Message::onDisconnected);
-    connect(&m_WebSocket, static_cast<void(QWebSocket::*)(QAbstractSocket::SocketError)>(&QWebSocket::error), this,
-            &Message::onError);
+    for (auto &nodeManager : m_NodeManagers)
+    {
+        connect(nodeManager->message(), &Node::connected, this, &Message::onConnected);
+        connect(nodeManager->message(), &Node::disconnected, this, &Message::onDisconnected);
+        connect(nodeManager->message(), &Node::onTextReceived, this, &Message::onTextReceived);
+    }
 
     connect(manager, &Ekos::Manager::newModule, this, &Message::sendModuleState);
 
     m_ThrottleTS = QDateTime::currentDateTime();
+
+    m_PendingPropertiesTimer.setInterval(500);
+    connect(&m_PendingPropertiesTimer, &QTimer::timeout, this, &Message::sendPendingProperties);
 }
 
-void Message::connectServer()
-{
-    QUrl requestURL(m_URL);
-
-    QUrlQuery query;
-    query.addQueryItem("username", m_AuthResponse["username"].toString());
-    query.addQueryItem("token", m_AuthResponse["token"].toString());
-    if (m_AuthResponse.contains("remoteToken"))
-        query.addQueryItem("remoteToken", m_AuthResponse["remoteToken"].toString());
-    query.addQueryItem("email", m_AuthResponse["email"].toString());
-    query.addQueryItem("from_date", m_AuthResponse["from_date"].toString());
-    query.addQueryItem("to_date", m_AuthResponse["to_date"].toString());
-    query.addQueryItem("plan_id", m_AuthResponse["plan_id"].toString());
-    query.addQueryItem("type", m_AuthResponse["type"].toString());
-    query.addQueryItem("version", KSTARS_VERSION);
-
-    requestURL.setPath("/message/ekos");
-    requestURL.setQuery(query);
-
-
-    m_WebSocket.open(requestURL);
-
-    qCInfo(KSTARS_EKOS) << "Connecting to Websocket server at" << requestURL.toDisplayString();
-}
-
-void Message::disconnectServer()
-{
-    m_WebSocket.close();
-}
-
+///////////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////////
 void Message::onConnected()
 {
-    qCInfo(KSTARS_EKOS) << "Connected to Message Websocket server at" << m_URL.toDisplayString();
+    auto node = qobject_cast<Node*>(sender());
+    if (!node)
+        return;
 
-    m_isConnected = true;
-    m_ReconnectTries = 0;
-
-    connect(&m_WebSocket, &QWebSocket::textMessageReceived,  this, &Message::onTextReceived, Qt::UniqueConnection);
+    qCInfo(KSTARS_EKOS) << "Connected to Message Websocket server at" << node->url().toDisplayString();
 
+    m_PendingPropertiesTimer.start();
     sendConnection();
     sendProfiles();
-
     emit connected();
 }
 
+///////////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////////
 void Message::onDisconnected()
 {
-    qCInfo(KSTARS_EKOS) << "Disconnected from Message Websocket server.";
-    m_isConnected = false;
-    disconnect(&m_WebSocket, &QWebSocket::textMessageReceived,  this, &Message::onTextReceived);
-    m_PropertyCache.clear();
+    auto node = qobject_cast<Node*>(sender());
+    if (!node)
+        return;
 
-    emit disconnected();
-}
+    qCInfo(KSTARS_EKOS) << "Disconnected from Message Websocket server at" << node->url().toDisplayString();
 
-void Message::onError(QAbstractSocket::SocketError error)
-{
-    qCritical(KSTARS_EKOS) << "Websocket connection error" << m_WebSocket.errorString();
-    if (error == QAbstractSocket::RemoteHostClosedError ||
-            error == QAbstractSocket::ConnectionRefusedError)
+    if (isConnected() == false)
     {
-        if (m_ReconnectTries++ < RECONNECT_MAX_TRIES)
-            QTimer::singleShot(RECONNECT_INTERVAL, this, &Message::connectServer);
+        m_PendingPropertiesTimer.stop();
+        emit disconnected();
     }
 }
 
-
+///////////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////////
 void Message::onTextReceived(const QString &message)
 {
+    auto node = qobject_cast<Node*>(sender());
+    if (!node)
+        return;
+
     qCInfo(KSTARS_EKOS) << "Websocket Message" << message;
     QJsonParseError error;
     auto serverMessage = QJsonDocument::fromJson(message.toUtf8(), &error);
@@ -124,15 +105,6 @@ void Message::onTextReceived(const QString &message)
         return;
     }
 
-    // TODO add check to verify token!
-    //    const QString serverToken = serverMessage.object().value("token").toString();
-
-    //    if (serverToken != token)
-    //    {
-    //        qCWarning(KSTARS_EKOS) << "Invalid token received from server!" << serverToken;
-    //        return;
-    //    }
-
     const QJsonObject msgObj = serverMessage.object();
     const QString command = msgObj["type"].toString();
     const QJsonObject payload = msgObj["payload"].toObject();
@@ -143,7 +115,7 @@ void Message::onTextReceived(const QString &message)
     }
     else if (command == commands[LOGOUT])
     {
-        emit expired();
+        emit expired(node->url());
         return;
     }
     else if (command == commands[SET_CLIENT_STATE])
@@ -259,9 +231,23 @@ void Message::onTextReceived(const QString &message)
 
 }
 
+///////////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////////
+bool Message::isConnected() const
+{
+    return std::any_of(m_NodeManagers.begin(), m_NodeManagers.end(), [](auto & nodeManager)
+    {
+        return nodeManager->message()->isConnected();
+    });
+}
+
+///////////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendStellarSolverProfiles()
 {
-    if (m_isConnected == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
+    if (m_Manager->getEkosStartingStatus() != Ekos::Success)
         return;
 
     QJsonObject profiles;
@@ -283,9 +269,6 @@ void Message::sendStellarSolverProfiles()
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendDrivers()
 {
-    if (m_isConnected == false)
-        return;
-
     sendResponse(commands[GET_DRIVERS], DriverManager::Instance()->getDriverList());
 }
 
@@ -294,7 +277,7 @@ void Message::sendDrivers()
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendDevices()
 {
-    if (m_isConnected == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
+    if (m_Manager->getEkosStartingStatus() != Ekos::Success)
         return;
 
     QJsonArray deviceList;
@@ -320,7 +303,7 @@ void Message::sendDevices()
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendTrains()
 {
-    if (m_isConnected == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
+    if (m_Manager->getEkosStartingStatus() != Ekos::Success)
         return;
 
     QJsonArray trains;
@@ -336,7 +319,7 @@ void Message::sendTrains()
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendTrainProfiles()
 {
-    if (m_isConnected == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
+    if (m_Manager->getEkosStartingStatus() != Ekos::Success)
         return;
 
     auto profiles = Ekos::ProfileSettings::Instance()->getSettings();
@@ -349,8 +332,7 @@ void Message::sendTrainProfiles()
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::requestOpticalTrains(bool show)
 {
-    m_WebSocket.sendTextMessage(QJsonDocument({{"type", commands[TRAIN_CONFIGURATION_REQUESTED]}, {"payload", show}}).toJson(
-        QJsonDocument::Compact));
+    sendResponse(commands[TRAIN_CONFIGURATION_REQUESTED], show);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -358,9 +340,6 @@ void Message::requestOpticalTrains(bool show)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendScopes()
 {
-    if (m_isConnected == false)
-        return;
-
     QJsonArray scopeList;
 
     QList<OAL::Scope *> allScopes;
@@ -377,9 +356,6 @@ void Message::sendScopes()
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendDSLRLenses()
 {
-    if (m_isConnected == false)
-        return;
-
     QJsonArray dslrList;
 
     QList<OAL::DSLRLens *> allDslrLens;
@@ -828,14 +804,22 @@ void Message::processAlignCommands(const QString &command, const QJsonObject &pa
         align->abort();
     else if (command == commands[ALIGN_LOAD_AND_SLEW])
     {
-        QString filename = QDir::tempPath() + QDir::separator() +
-                           QString("XXXXXXloadslew.%1").arg(payload["ext"].toString("fits"));
-        QTemporaryFile file(filename);
-        file.setAutoRemove(false);
-        file.open();
-        file.write(QByteArray::fromBase64(payload["data"].toString().toLatin1()));
-        file.close();
-        align->loadAndSlew(file.fileName());
+        // Check if we have filename payload first
+        if (payload.contains("filename"))
+        {
+            align->loadAndSlew(payload["filename"].toString());
+        }
+        else
+        {
+            QString filename = QDir::tempPath() + QDir::separator() +
+                               QString("XXXXXXloadslew.%1").arg(payload["ext"].toString("fits"));
+            QTemporaryFile file(filename);
+            file.setAutoRemove(false);
+            file.open();
+            file.write(QByteArray::fromBase64(payload["data"].toString().toLatin1()));
+            file.close();
+            align->loadAndSlew(file.fileName());
+        }
     }
     else if (command == commands[ALIGN_MANUAL_ROTATOR_TOGGLE])
     {
@@ -848,7 +832,7 @@ void Message::processAlignCommands(const QString &command, const QJsonObject &pa
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::setAlignStatus(Ekos::AlignState newState)
 {
-    if (m_isConnected == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
+    if (m_Manager->getEkosStartingStatus() != Ekos::Success)
         return;
 
     QJsonObject alignState =
@@ -864,7 +848,7 @@ void Message::setAlignStatus(Ekos::AlignState newState)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::setAlignSolution(const QVariantMap &solution)
 {
-    if (m_isConnected == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
+    if (m_Manager->getEkosStartingStatus() != Ekos::Success)
         return;
 
     QJsonObject alignState =
@@ -1029,7 +1013,7 @@ void Message::processPolarCommands(const QString &command, const QJsonObject &pa
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::setPAHStage(Ekos::PolarAlignmentAssistant::Stage stage)
 {
-    if (m_isConnected == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
+    if (isConnected() == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
         return;
 
     Q_UNUSED(stage)
@@ -1058,7 +1042,7 @@ void Message::setPAHStage(Ekos::PolarAlignmentAssistant::Stage stage)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::setPAHMessage(const QString &message)
 {
-    if (m_isConnected == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
+    if (isConnected() == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
         return;
 
     QTextDocument doc;
@@ -1076,7 +1060,7 @@ void Message::setPAHMessage(const QString &message)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::setPolarResults(QLineF correctionVector, double polarError, double azError, double altError)
 {
-    if (m_isConnected == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
+    if (isConnected() == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
         return;
 
     this->correctionVector = correctionVector;
@@ -1106,7 +1090,7 @@ void Message::setPolarResults(QLineF correctionVector, double polarError, double
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::setUpdatedErrors(double total, double az, double alt)
 {
-    if (m_isConnected == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
+    if (isConnected() == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
         return;
 
     QJsonObject error =
@@ -1124,7 +1108,7 @@ void Message::setUpdatedErrors(double total, double az, double alt)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::setPAHEnabled(bool enabled)
 {
-    if (m_isConnected == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
+    if (m_Manager->getEkosStartingStatus() != Ekos::Success)
         return;
 
     QJsonObject polarState =
@@ -1158,7 +1142,6 @@ void Message::processProfileCommands(const QString &command, const QJsonObject &
         KStars::Instance()->clearAllViewers();
 
         m_PropertySubscriptions.clear();
-        m_PropertyCache.clear();
     }
     else if (command == commands[ADD_PROFILE])
     {
@@ -1495,7 +1478,6 @@ void Message::processDeviceCommands(const QString &command, const QJsonObject &p
     if (device.isEmpty() && command == commands[DEVICE_PROPERTY_UNSUBSCRIBE])
     {
         m_PropertySubscriptions.clear();
-        m_PropertyCache.clear();
         return;
     }
 
@@ -1508,8 +1490,7 @@ void Message::processDeviceCommands(const QString &command, const QJsonObject &p
     {
         QJsonObject propObject;
         if (oneDevice->getJSONProperty(payload["property"].toString(), propObject, payload["compact"].toBool(true)))
-            m_WebSocket.sendTextMessage(QJsonDocument({{"type", commands[DEVICE_PROPERTY_GET]}, {"payload", propObject}}).toJson(
-            QJsonDocument::Compact));
+            sendResponse(commands[DEVICE_PROPERTY_GET], propObject);
     }
     // Set specific property
     else if (command == commands[DEVICE_PROPERTY_SET])
@@ -1533,8 +1514,7 @@ void Message::processDeviceCommands(const QString &command, const QJsonObject &p
             {"properties", properties}
         };
 
-        m_WebSocket.sendTextMessage(QJsonDocument({{"type", commands[DEVICE_GET]}, {"payload", response}}).toJson(
-            QJsonDocument::Compact));
+        sendResponse(commands[DEVICE_GET], response);
     }
     // Subscribe to one or more properties
     // When subscribed, the updates are immediately pushed as soon as they are received.
@@ -2123,8 +2103,7 @@ KStarsDateTime Message::getNextDawn()
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::requestDSLRInfo(const QString &cameraName)
 {
-    m_WebSocket.sendTextMessage(QJsonDocument({{"type", commands[DSLR_GET_INFO]}, {"payload", cameraName}}).toJson(
-        QJsonDocument::Compact));
+    sendResponse(commands[DSLR_GET_INFO], cameraName);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -2132,8 +2111,7 @@ void Message::requestDSLRInfo(const QString &cameraName)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::requestPortSelection(bool show)
 {
-    m_WebSocket.sendTextMessage(QJsonDocument({{"type", commands[GET_PROFILE_PORT_SELECTION]}, {"payload", show}}).toJson(
-        QJsonDocument::Compact));
+    sendResponse(commands[GET_PROFILE_PORT_SELECTION], show);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -2141,8 +2119,7 @@ void Message::requestPortSelection(bool show)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendDialog(const QJsonObject &message)
 {
-    m_WebSocket.sendTextMessage(QJsonDocument({{"type", commands[DIALOG_GET_INFO]}, {"payload", message}}).toJson(
-        QJsonDocument::Compact));
+    sendResponse(commands[DIALOG_GET_INFO], message);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -2150,7 +2127,10 @@ void Message::sendDialog(const QJsonObject &message)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendResponse(const QString &command, const QJsonObject &payload)
 {
-    m_WebSocket.sendTextMessage(QJsonDocument({{"type", command}, {"payload", payload}}).toJson(QJsonDocument::Compact));
+    for (auto &nodeManager : m_NodeManagers)
+    {
+        nodeManager->message()->sendResponse(command, payload);
+    }
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -2158,7 +2138,44 @@ void Message::sendResponse(const QString &command, const QJsonObject &payload)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendResponse(const QString &command, const QJsonArray &payload)
 {
-    m_WebSocket.sendTextMessage(QJsonDocument({{"type", command}, {"payload", payload}}).toJson(QJsonDocument::Compact));
+    for (auto &nodeManager : m_NodeManagers)
+    {
+        nodeManager->message()->sendResponse(command, payload);
+    }
+}
+
+///////////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////////
+void Message::sendResponse(const QString &command, const QString &payload)
+{
+    for (auto &nodeManager : m_NodeManagers)
+    {
+        nodeManager->message()->sendResponse(command, payload);
+    }
+}
+
+///////////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////////
+void Message::sendResponse(const QString &command, bool payload)
+{
+    for (auto &nodeManager : m_NodeManagers)
+    {
+        nodeManager->message()->sendResponse(command, payload);
+    }
+}
+
+///////////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////////
+void Message::autofocusAborted()
+{
+    QJsonObject cStatus =
+    {
+        {"status", "Aborted"}
+    };
+    sendResponse(commands[NEW_FOCUS_STATE], cStatus);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -2166,9 +2183,6 @@ void Message::sendResponse(const QString &command, const QJsonArray &payload)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::updateMountStatus(const QJsonObject &status, bool throttle)
 {
-    if (m_isConnected == false)
-        return;
-
     if (throttle)
     {
         QDateTime now = QDateTime::currentDateTime();
@@ -2187,9 +2201,6 @@ void Message::updateMountStatus(const QJsonObject &status, bool throttle)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::updateCaptureStatus(const QJsonObject &status)
 {
-    if (m_isConnected == false)
-        return;
-
     sendResponse(commands[NEW_CAPTURE_STATE], status);
 }
 
@@ -2198,9 +2209,6 @@ void Message::updateCaptureStatus(const QJsonObject &status)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::updateFocusStatus(const QJsonObject &status)
 {
-    if (m_isConnected == false)
-        return;
-
     sendResponse(commands[NEW_FOCUS_STATE], status);
 }
 
@@ -2209,9 +2217,6 @@ void Message::updateFocusStatus(const QJsonObject &status)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::updateGuideStatus(const QJsonObject &status)
 {
-    if (m_isConnected == false)
-        return;
-
     sendResponse(commands[NEW_GUIDE_STATE], status);
 }
 
@@ -2220,9 +2225,6 @@ void Message::updateGuideStatus(const QJsonObject &status)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::updateDomeStatus(const QJsonObject &status)
 {
-    if (m_isConnected == false)
-        return;
-
     sendResponse(commands[NEW_DOME_STATE], status);
 }
 
@@ -2231,9 +2233,6 @@ void Message::updateDomeStatus(const QJsonObject &status)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::updateCapStatus(const QJsonObject &status)
 {
-    if (m_isConnected == false)
-        return;
-
     sendResponse(commands[NEW_CAP_STATE], status);
 }
 
@@ -2242,14 +2241,12 @@ void Message::updateCapStatus(const QJsonObject &status)
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendConnection()
 {
-    if (m_isConnected == false)
-        return;
-
     QJsonObject connectionState =
     {
         {"connected", true},
         {"online", m_Manager->getEkosStartingStatus() == Ekos::Success}
     };
+
     sendResponse(commands[NEW_CONNECTION_STATE], connectionState);
 }
 
@@ -2258,9 +2255,6 @@ void Message::sendConnection()
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendStates()
 {
-    if (m_isConnected == false)
-        return;
-
     // Send capture sequence if one exists
     if (m_Manager->captureModule())
     {
@@ -2328,7 +2322,7 @@ void Message::sendStates()
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendEvent(const QString &message, KSNotification::EventSource source, KSNotification::EventType event)
 {
-    if (m_isConnected == false || Options::ekosLiveNotifications() == false)
+    if (Options::ekosLiveNotifications() == false)
         return;
 
     QJsonObject newEvent =
@@ -2347,9 +2341,6 @@ void Message::sendEvent(const QString &message, KSNotification::EventSource sour
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendManualRotatorStatus(double currentPA, double targetPA, double threshold)
 {
-    if (m_isConnected == false)
-        return;
-
     QJsonObject request = {{ "currentPA", currentPA}, {"targetPA", targetPA}, {"threshold", threshold}};
     sendResponse(commands[ALIGN_MANUAL_ROTATOR_STATUS], request);
 }
@@ -2385,8 +2376,7 @@ void Message::processNewProperty(INDI::Property prop)
 
     QJsonObject propObject;
     ISD::propertyToJson(prop, propObject, false);
-    m_WebSocket.sendTextMessage(QJsonDocument({{"type", commands[DEVICE_PROPERTY_ADD]}, {"payload", propObject}}).toJson(
-        QJsonDocument::Compact));
+    sendResponse(commands[DEVICE_PROPERTY_ADD], propObject);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -2400,8 +2390,25 @@ void Message::processDeleteProperty(INDI::Property prop)
         {"name", prop.getName()}
     };
 
-    m_WebSocket.sendTextMessage(QJsonDocument({{"type", commands[DEVICE_PROPERTY_REMOVE]}, {"payload", payload}}).toJson(
-        QJsonDocument::Compact));
+    sendResponse(commands[DEVICE_PROPERTY_REMOVE], payload);
+}
+
+///////////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////////
+void Message::processMessage(const QSharedPointer<ISD::GenericDevice> &device, int id)
+{
+    if (Options::ekosLiveNotifications() == false)
+        return;
+
+    auto message = QString::fromStdString(device->getBaseDevice().messageQueue(id));
+    QJsonObject payload =
+    {
+        {"device", device->getDeviceName()},
+        {"message", message}
+    };
+
+    sendResponse(commands[DEVICE_MESSAGE], payload);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
@@ -2414,30 +2421,35 @@ void Message::processUpdateProperty(INDI::Property prop)
         QSet<QString> subProps = m_PropertySubscriptions[prop.getDeviceName()];
         if (subProps.contains(prop.getName()))
         {
-            auto propObject = new QJsonObject();
-            ISD::propertyToJson(prop, *propObject);
-
-            if (m_PropertyCache.contains(prop.getName()) && *m_PropertyCache[prop.getName()] == *propObject)
-            {
-                delete (propObject);
-                return;
-            }
-
-            m_WebSocket.sendTextMessage(QJsonDocument({{"type", commands[DEVICE_PROPERTY_GET]}, {"payload", *propObject}}).toJson(
-                QJsonDocument::Compact));
-            m_PropertyCache.insert(prop.getName(), propObject);
+            m_PendingProperties.remove(prop);
+            m_PendingProperties.insert(prop);
         }
     }
 }
 
+///////////////////////////////////////////////////////////////////////////////////////////
+///
+///////////////////////////////////////////////////////////////////////////////////////////
+void Message::sendPendingProperties()
+{
+    for (auto &prop : m_PendingProperties)
+    {
+        if (prop->isValid())
+        {
+            QJsonObject propObject;
+            ISD::propertyToJson(*prop, propObject);
+            sendResponse(commands[DEVICE_PROPERTY_GET], propObject);
+        }
+    }
+
+    m_PendingProperties.clear();
+}
+
 ///////////////////////////////////////////////////////////////////////////////////////////
 ///
 ///////////////////////////////////////////////////////////////////////////////////////////
 void Message::sendModuleState(const QString &name)
 {
-    if (m_isConnected == false)
-        return;
-
     if (name == "Capture")
     {
         QJsonObject captureState = {{ "status", getCaptureStatusString(m_Manager->captureModule()->status(), false)}};
@@ -2600,8 +2612,6 @@ void Message::invokeMethod(QObject *context, const QJsonObject &payload)
             QMetaObject::invokeMethod(context, name, arg1, arg2, arg3, arg4);
             break;
     }
-
-
 }
 
 }
