@@ -697,7 +697,7 @@ void InternalGuider::setImageData(const QSharedPointer<FITSData> &data)
         // IS8601 contains colons but they are illegal under Windows OS, so replacing them with '-'
         // The timestamp is no longer ISO8601 but it should solve interoperality issues between different OS hosts
         QString name     = "guide_frame_" + now.toString("HH-mm-ss") + ".fits";
-        QString filename = path + QStringLiteral("/") + name + QStringLiteral("[compress R 100,100]");
+        QString filename = path + QStringLiteral("/") + name;
         m_ImageData->saveImage(filename);
     }
 }
