@@ -1652,9 +1652,6 @@ void Mount::setupOpticalTrainManager()
         refreshOpticalTrain();
         emit trainChanged();
     });
-    refreshOpticalTrain();
-
-
 }
 
 void Mount::refreshOpticalTrain()
@@ -1673,8 +1670,8 @@ void Mount::refreshOpticalTrain()
         // If train not found, select the first one available.
         if (OpticalTrainManager::Instance()->exists(id) == false)
         {
+            qCWarning(KSTARS_EKOS_MOUNT) << "Optical train doesn't exist for id" << id;
             id = OpticalTrainManager::Instance()->id(opticalTrainCombo->itemText(0));
-            ProfileSettings::Instance()->setOneSetting(ProfileSettings::MountOpticalTrain, id);
         }
 
         auto name = OpticalTrainManager::Instance()->name(id);
@@ -2011,7 +2008,7 @@ void Mount::connectSettings()
     connect(mf_state.get(), &MeridianFlipState::slewTelescope, [&](SkyPoint pos)
     {
         if (m_Mount)
-            m_Mount->Slew(&pos);
+            m_Mount->Slew(&pos, (m_Mount->canFlip() && Options::forcedFlip()));
     });
 
     // Train combo box should NOT be synced.
