@@ -31,13 +31,7 @@ ConcreteDevice::ConcreteDevice(ISD::GenericDevice *parent) : GDInterface(parent)
     // Signal --> Signal
     connect(parent, &GenericDevice::propertyDefined, this, &ConcreteDevice::propertyDefined);
     connect(parent, &GenericDevice::propertyDeleted, this, &ConcreteDevice::propertyDeleted);
-
-    // Signal --> Signal
-    connect(parent, &GenericDevice::switchUpdated, this, &ConcreteDevice::switchUpdated);
-    connect(parent, &GenericDevice::textUpdated, this, &ConcreteDevice::textUpdated);
-    connect(parent, &GenericDevice::numberUpdated, this, &ConcreteDevice::numberUpdated);
-    connect(parent, &GenericDevice::lightUpdated, this, &ConcreteDevice::lightUpdated);
-    connect(parent, &GenericDevice::BLOBUpdated, this, &ConcreteDevice::BLOBUpdated);
+    connect(parent, &GenericDevice::propertyUpdated, this, &ConcreteDevice::propertyUpdated);
 
     // Signal --> Slots
     connect(parent, &GenericDevice::propertyDefined, this, [this](INDI::Property value)
@@ -47,10 +41,7 @@ ConcreteDevice::ConcreteDevice(ISD::GenericDevice *parent) : GDInterface(parent)
         registerProperty(value);
     });
     connect(parent, &GenericDevice::propertyDeleted, this, &ConcreteDevice::removeProperty);
-    connect(parent, &GenericDevice::switchUpdated, this, &ConcreteDevice::processSwitch);
-    connect(parent, &GenericDevice::textUpdated, this, &ConcreteDevice::processText);
-    connect(parent, &GenericDevice::numberUpdated, this, &ConcreteDevice::processNumber);
-    connect(parent, &GenericDevice::lightUpdated, this, &ConcreteDevice::processLight);
+    connect(parent, &GenericDevice::propertyUpdated, this, &ConcreteDevice::updateProperty);
 }
 
 void ConcreteDevice::registeProperties()
@@ -60,6 +51,29 @@ void ConcreteDevice::registeProperties()
         registerProperty(oneProperty);
 }
 
+void ConcreteDevice::updateProperty(INDI::Property prop)
+{
+    switch (prop.getType())
+    {
+        case INDI_SWITCH:
+            processSwitch(prop);
+            break;
+        case INDI_NUMBER:
+            processNumber(prop);
+            break;
+        case INDI_TEXT:
+            processText(prop);
+            break;
+        case INDI_LIGHT:
+            processLight(prop);
+            break;
+        case INDI_BLOB:
+            processBLOB(prop);
+        default:
+            break;
+    }
+}
+
 void ConcreteDevice::processProperties()
 {
     // Register all properties first
@@ -68,16 +82,19 @@ void ConcreteDevice::processProperties()
         switch (oneProperty.getType())
         {
             case INDI_SWITCH:
-                processSwitch(oneProperty.getSwitch());
+                processSwitch(oneProperty);
                 break;
             case INDI_NUMBER:
-                processNumber(oneProperty.getNumber());
+                processNumber(oneProperty);
                 break;
             case INDI_TEXT:
-                processText(oneProperty.getText());
+                processText(oneProperty);
                 break;
             case INDI_LIGHT:
-                processLight(oneProperty.getLight());
+                processLight(oneProperty);
+                break;
+            case INDI_BLOB:
+                processBLOB(oneProperty);
                 break;
             default:
                 break;
@@ -87,65 +104,37 @@ void ConcreteDevice::processProperties()
 
 INDI::PropertyView<INumber> *ConcreteDevice::getNumber(const QString &name) const
 {
-    return m_Parent->getBaseDevice()->getNumber(name.toLatin1().constData());
+    return m_Parent->getBaseDevice().getNumber(name.toLatin1().constData());
 }
 
 INDI::PropertyView<IText>   *ConcreteDevice::getText(const QString &name) const
 {
-    return m_Parent->getBaseDevice()->getText(name.toLatin1().constData());
+    return m_Parent->getBaseDevice().getText(name.toLatin1().constData());
 }
 
 INDI::PropertyView<ISwitch> *ConcreteDevice::getSwitch(const QString &name) const
 {
-    return m_Parent->getBaseDevice()->getSwitch(name.toLatin1().constData());
+    return m_Parent->getBaseDevice().getSwitch(name.toLatin1().constData());
 }
 
 INDI::PropertyView<ILight>  *ConcreteDevice::getLight(const QString &name) const
 {
-    return m_Parent->getBaseDevice()->getLight(name.toLatin1().constData());
+    return m_Parent->getBaseDevice().getLight(name.toLatin1().constData());
 }
 
 INDI::PropertyView<IBLOB>   *ConcreteDevice::getBLOB(const QString &name) const
 {
-    return m_Parent->getBaseDevice()->getBLOB(name.toLatin1().constData());
+    return m_Parent->getBaseDevice().getBLOB(name.toLatin1().constData());
 }
 
-void ConcreteDevice::sendNewText(ITextVectorProperty *pp)
+void ConcreteDevice::sendNewProperty(INDI::Property prop)
 {
-    m_Parent->getClientManager()->sendNewText(pp);
+    m_Parent->sendNewProperty(prop);
 }
 
 QString ConcreteDevice::getMessage(int id) const
 {
-    return QString::fromStdString(m_Parent->getBaseDevice()->messageQueue(id));
-}
-
-
-void ConcreteDevice::sendNewText(const char *deviceName, const char *propertyName, const char *elementName,
-                                 const char *text)
-{
-    m_Parent->getClientManager()->sendNewText(deviceName, propertyName, elementName, text);
-}
-
-
-void ConcreteDevice::sendNewNumber(INumberVectorProperty *pp)
-{
-    m_Parent->getClientManager()->sendNewNumber(pp);
-}
-
-void ConcreteDevice::sendNewNumber(const char *deviceName, const char *propertyName, const char *elementName, double value)
-{
-    m_Parent->getClientManager()->sendNewNumber(deviceName, propertyName, elementName, value);
-}
-
-void ConcreteDevice::sendNewSwitch(ISwitchVectorProperty *pp)
-{
-    m_Parent->getClientManager()->sendNewSwitch(pp);
-}
-
-void ConcreteDevice::sendNewSwitch(const char *deviceName, const char *propertyName, const char *elementName)
-{
-    m_Parent->getClientManager()->sendNewSwitch(deviceName, propertyName, elementName);
+    return QString::fromStdString(m_Parent->getBaseDevice().messageQueue(id));
 }
 
 INDI::Property ConcreteDevice::getProperty(const QString &name) const
