@@ -343,14 +343,14 @@ void SkyMap::keyPressEvent(QKeyEvent *e)
         {
             // Toggle relativistic corrections
             Options::setUseRelativistic(!Options::useRelativistic());
-            qDebug() << "Relativistic corrections: " << Options::useRelativistic();
+            qDebug() << Q_FUNC_INFO << "Relativistic corrections: " << Options::useRelativistic();
             forceUpdate();
             break;
         }
 
         case Qt::Key_A:
             Options::setUseAntialias(!Options::useAntialias());
-            qDebug() << "Use Antialiasing: " << Options::useAntialias();
+            qDebug() << Q_FUNC_INFO << "Use Antialiasing: " << Options::useAntialias();
             forceUpdate();
             break;
 
@@ -537,6 +537,33 @@ void SkyMap::mouseMoveEvent(QMouseEvent *e)
         }
     }
 
+    // Are we setting the skymap rotation?
+    if (rotationStart.x() > 0 && rotationStart.y() > 0)
+    {
+        // stop the operation if the user let go of SHIFT
+        if (!(e->modifiers() & Qt::ShiftModifier))
+        {
+            rotationStart = QPoint(); // invalidate
+            rotationStartAngle = dms(); // NaN
+            slewing = false;
+            forceUpdate();
+            return;
+        }
+        else
+        {
+            // Compute the rotation
+            const float start_x = rotationStart.x() - width() / 2.0f;
+            const float start_y = height() / 2.0f - rotationStart.y();
+
+            const float curr_x = e->pos().x() - width() / 2.0f;
+            const float curr_y = height() / 2.0f - e->pos().y();
+
+            const dms angle {(std::atan2(curr_y, curr_x) - std::atan2(start_y, start_x)) / dms::DegToRad };
+            slotSetSkyRotation((rotationStartAngle - angle).Degrees());
+            return;
+        }
+    }
+
     if (projector()->unusablePoint(e->pos()))
         return; // break if point is unusable
 
@@ -647,9 +674,9 @@ void SkyMap::mouseMoveEvent(QMouseEvent *e)
 
 void SkyMap::wheelEvent(QWheelEvent *e)
 {
-    if (e->delta() > 0)
+    if (e->angleDelta().y() > 0)
         zoomInOrMagStep(e->modifiers());
-    else if (e->delta() < 0)
+    else if (e->angleDelta().y() < 0)
         zoomOutOrMagStep(e->modifiers());
 }
 
@@ -686,6 +713,16 @@ void SkyMap::mouseReleaseEvent(QMouseEvent *e)
         slotCancelLegendPreviewMode();
     }
 
+    // Are we setting the skymap rotation?
+    if (rotationStart.x() > 0 && rotationStart.y() > 0)
+    {
+        rotationStart = QPoint(); // invalidate
+        rotationStartAngle = dms(); // NaN
+        slewing = false;
+        forceUpdateNow();
+        return;
+    }
+
     //false if double-clicked, because it's unset there.
     if (mouseButtonDown)
     {
@@ -718,6 +755,17 @@ void SkyMap::mousePressEvent(QMouseEvent *e)
         return;
     }
 
+    if ((e->modifiers() & Qt::ShiftModifier) && (e->button() == Qt::LeftButton))
+    {
+        // Skymap rotation mode
+        rotationStart = e->pos();
+        rotationStartAngle = dms(Options::skyRotation());
+        slewing = true;
+        setRotationMouseCursor();
+        forceUpdate();
+        return;
+    }
+
     // if button is down and cursor is not moved set the move cursor after 500 ms
     //QTimer::singleShot(500, this, SLOT(setMouseMoveCursor()));
 
